<?php

//
// innovaphone mail PHP class
// copyright (c) innovaphone 2012 - 2014
//

require_once('innovaphone.mail.attachment.class.php');

class InnovaphoneMail {

    protected $messageId;
    protected $sender;
    protected $recipients;
    protected $ccRecipients;
    protected $priority;        //Priority: "urgent", "normal", "non-urgent"
                                //Importance: "high", "normal", "low"
                                //X-Priority: "1" (highest), "3" (normal), "5" (lowest)
    protected $date;
    protected $subject;
    protected $textPlain;
    protected $textHtml;
    protected $textHtmlCharset;
    protected $attachments;


    // class constructor
    public function __construct($messageId,
        $sender,
        $recipients,
        $ccRecipients,
        $subject,
        $textPlain,
        $textHtml,
        $textHtmlCharset,
        $attachments) {
        $this->messageId        = $messageId;
        $this->sender           = $sender;
        $this->recipients       = $recipients;
        $this->ccRecipients     = $ccRecipients;
        $this->date             = new DateTime();
        $this->priority         = "normal";
        $this->subject          = trim($subject);
        $this->textPlain        = trim($textPlain);
        $this->textHtml         = $textHtml;
        $this->textHtmlCharset  = $textHtmlCharset;
        $this->attachments      = $attachments;
    }

    public function getMessageId() {
        return $this->messageId;
    }

    public function getSender() {
        return $this->sender;
    }

    public function getSenderAddress() {
        return strtolower($this->sender->mailbox . '@' . $this->sender->host);
    }
    
    public function getSenderName() {
        return isset($this->sender->personal) ? iconv_mime_decode($this->sender->personal, 0, "UTF-8") : "";
    }

    public function getSenderMailbox() {
        return strtolower($this->sender->mailbox);
    }

    public function getRecipients() {
        return $this->recipients;
    }

    public function getCcRecipients() {
        return $this->ccRecipients;
    }

    public function getDate() {
        return $this->date;
    }

    public function getPriority() {
        return $this->priority;
    }

    public function getSubject() {
        return $this->subject;
    }

    public function getTextPlain() {
        return $this->textPlain;
    }

    public function getTextHtml() {
        return $this->textHtml;
    }

    public function getTextHtmlCharset() {
        return $this->textHtmlCharset;
    }

    public function getAttachments() {
        return $this->attachments;
    }

    public function setDate($date) {
        $this->date = $date;    
    }

    public function setPriority($priority) {
        if($priority == "urgent") {
            $this->priority = "urgent";
        }
        else if($priority == "normal") {
            $this->priority = "normal";
        }
        else if($priority == "non-urgent") {
            $this->priority = "non-urgent";
        }
    }
    
    public function setImportance($importance) {
        if($importance == "high") {
            $this->priority = "urgent";
        }
        else if($importance == "normal") {
            $this->priority = "normal";
        }
        else if($importance == "low") {
            $this->priority = "non-urgent";
        }
    }

    public function getImportance() {
        if($this->priority == "urgent") {
            return "high";
        }
        else if($this->priority == "normal") {
            return "normal";
        }
        else if($this->priority == "non-urgent") {
            return "low";
        }
    }
    
    public function setXPriority($xPriority) {
        if($xPriority == 1) {
            $this->priority = "urgent";
        }
        else if($xPriority == 3) {
            $this->priority = "normal";
        }
        else if($xPriority == 5) {
            $this->priority = "non-urgent";
        }
    }
    
    public function getXPriority() {
        if($this->priority == "urgent") {
            return "1";
        }
        else if($this->priority == "normal") {
            return "3";
        }
        else if($this->priority == "non-urgent") {
            return "5";
        }
    }
}

?>